# AI Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.10.0] - 2024-06-20

- Add LiteLLM support by @tomusher in https://github.com/wagtail/wagtail-vector-index/pull/64
- Refactor vector indexes in to single type by @tomusher in https://github.com/wagtail/wagtail-vector-index/pull/65
- Docs: Update 'Indexing across models' example to include all necessary steps by @ababic in https://github.com/wagtail/wagtail-vector-index/pull/70
- Resolved bug in index.query() that prevented content from similar documents to be included i then LLM query by @berry in https://github.com/wagtail/wagtail-vector-index/pull/69


## [0.9.0] - 2024-03-26

### Added

- Initial release


## [Unreleased]

<!-- TEMPLATE - keep below to copy for new releases -->
<!--


## [x.y.z] - YYYY-MM-DD

### Added

- ...

### Changed

- ...

### Removed

- ...

-->
